/* Common registers */
#define	W5200_MR	(0x0000)	/* Mode Register  (1 byte) */
#define	W5200_GAR	(0x0001)	/* Gateway register (4 bytes) */
#define	W5200_SUBR	(0x0005)	/* Subnet Mask Address (4 bytes) */
#define	W5200_SHAR	(0x0009)	/* Source Hardware Register (6 bytes) */
#define	W5200_SIPR	(0x000F)	/* Source IP address ( 4 bytes) */
#define	W5200_IR	(0x0013)	/* Interrupt Register (1 byte) */
#define	W5200_IMR2	(0x0016)	/* Socket Interrupt Mask (1 byte) */
#define	W5200_RTR	(0x0017)	/* Retry time (2 bytes) */
#define	W5200_IR2	(0x0034)	/* Socket Interrupt (1 byte) */
#define	W5200_PSTATUS	(0x0035)	/* PHY Status */
#define	W5200_IMR	(0x0036)	/* Interrupt Mask (1 byte) */

/* Socket_0 Registers */
#define	S0_MR		(0x4000)	/* Mode Register */
#define	S0_CR		(0x4001)	/* Command Register */
#define	S0_IR		(0x4002) 	/* Interupt Register */
#define	S0_SR		(0x4003)	/* Status Register */
#define	S0_PORT		(0x4004)	/* Source Port Register (2 bytes) */
#define	S0_DHAR		(0x4006)	/* Destination Hardware Address (6 bytes) */
#define	S0_DIPR		(0x400C)	/* Destination IP Address (4 bytes) */
#define	S0_MSSR		(0x4012)	/* Maximum Segment Size (2 bytes) */
#define	S0_RXMEM_SIZE	(0x401E)	/* Receive Memory Size  (in 2K units) */
#define	S0_TXMEM_SIZE	(0x401F)	/* Transmit Memory Size (in 2K units) */
#define	S0_FSR		(0x4020)	/* TX Free Size (2 bytes) */
#define	S0_TX_RD	(0x4022)	/* TX Read Pointer (2 bytes) */
#define	S0_TX_WR	(0x4024)	/* TX Write Pointer (2 bytes) */
#define	S0_RSR		(0x4026)	/* RX Received Size (2 bytes) */
#define	S0_RX_RD	(0x4028)	/* RX Read Pointer (2 bytes) */
#define	S0_RX_WR	(0x402A)	/* RX Write Pointer (2 bytes) */
#define	S0_IMR		(0x402C)	/* Socket Interrupt Mask */

/* Socket commands */
#define	CMD_OPEN	(0x01)		/* Sets up protocol TCP/UDP */
#define	CMD_LISTEN	(0x02) 		/* Only valid for TCP server */
#define	CMD_CONNECT	(0x04)		/* Only valid for TCP client */
#define CMD_DISCON	(0x08)		/* Only valid in TCP mode */
#define	CMD_CLOSE	(0x10) 		/* Close socket */
#define	CMD_SEND	(0x20)		/* Transmit buffered data */
#define	CMD_SEND_MAC	(0x21)		/* Used in UDP mode only */
#define	CMD_SEND_KEEP	(0x22)		/* Used in TCP mode only */
#define	CMD_RECV	(0x40) 		/* Process received data */

/* Socket Status Values */
#define	SOCK_CLOSED	(0x00)		/* Socket resources are released */
#define	SOCK_INIT	(0x13)		/* TCP OPEN command is given */
#define	SOCK_LISTEN	(0x14)		/* Operates in TCP server mode */
#define	SOCK_ESTABLISHED (0x17)		/* Connection is established */
#define	SOCK_CLOSE_WAIT	(0x1C)		/* Half-closed after FIN is received */
#define	SOCK_UDP	(0x22)		/* Opened in UDP mode */
#define SOCK_SYNSENT	(0x15)		/* SYN packet is sent to server */
#define	SOCK_SYNRECV	(0x16)		/* SYN packet is received from client */
#define	SOCK_FIN_WAIT	(0x18)		/* socket is closed */
#define	SOCK_CLOSING	(0x1A)		/* socket is closed */
#define	SOCK_TIME_WAIT	(0x1B)		/* socket is closed */
#define	SOCK_LAST_ACK	(0x1D)		/* socket is closed */
#define	SOCK_ARP	(0x01)		/* wait for ARP response */

/* Socket Interrupt Vector bits */
#define	INT_SEND_OK	(0x10)		/* SEND command is completed */
#define	INT_TIMEOUT	(0x08)		/* ARP_to or TCP_to event occured */
#define	INT_RECV	(0x04)		/* Packet is received from a peer */
#define	INT_DISCON	(0x02)		/* FIN or FIN/ACK packet is reveived */
#define	INT_CON		(0X01)		/* Connection with a peer is established */